==> zio-aws-fsx_3-5.17.191.2-sources.jar: zio/aws/fsx/model/DataRepositoryAssociation.scala <==
package zio.aws.fsx.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.fsx.model.primitives.{
  CreationTime,
  BatchImportMetaDataOnCreate,
  Megabytes,
  Namespace,
  FileSystemId,
  ResourceARN,
  ArchivePath,
  DataRepositoryAssociationId
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DataRepositoryAssociation(
    associationId: Optional[DataRepositoryAssociationId] = Optional.Absent,
    resourceARN: Optional[ResourceARN] = Optional.Absent,
    fileSystemId: Optional[FileSystemId] = Optional.Absent,
    lifecycle: Optional[zio.aws.fsx.model.DataRepositoryLifecycle] =
      Optional.Absent,
    failureDetails: Optional[zio.aws.fsx.model.DataRepositoryFailureDetails] =
      Optional.Absent,
    fileSystemPath: Optional[Namespace] = Optional.Absent,
    dataRepositoryPath: Optional[ArchivePath] = Optional.Absent,
    batchImportMetaDataOnCreate: Optional[BatchImportMetaDataOnCreate] =
      Optional.Absent,
    importedFileChunkSize: Optional[Megabytes] = Optional.Absent,
    s3: Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.fsx.model.Tag]] = Optional.Absent,
    creationTime: Optional[CreationTime] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation = {
    import DataRepositoryAssociation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
      .builder()
      .optionallyWith(
        associationId.map(value =>
          DataRepositoryAssociationId.unwrap(value): java.lang.String
        )
      )(_.associationId)
      .optionallyWith(
        resourceARN.map(value => ResourceARN.unwrap(value): java.lang.String)
      )(_.resourceARN)
      .optionallyWith(
        fileSystemId.map(value => FileSystemId.unwrap(value): java.lang.String)
      )(_.fileSystemId)
      .optionallyWith(lifecycle.map(value => value.unwrap))(_.lifecycle)
      .optionallyWith(failureDetails.map(value => value.buildAwsValue()))(
        _.failureDetails
      )
      .optionallyWith(
        fileSystemPath.map(value => Namespace.unwrap(value): java.lang.String)
      )(_.fileSystemPath)
      .optionallyWith(
        dataRepositoryPath.map(value =>
          ArchivePath.unwrap(value): java.lang.String
        )
      )(_.dataRepositoryPath)
      .optionallyWith(
        batchImportMetaDataOnCreate.map(value =>
          BatchImportMetaDataOnCreate.unwrap(value): java.lang.Boolean
        )
      )(_.batchImportMetaDataOnCreate)
      .optionallyWith(
        importedFileChunkSize.map(value => Megabytes.unwrap(value): Integer)
      )(_.importedFileChunkSize)
      .optionallyWith(s3.map(value => value.buildAwsValue()))(_.s3)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        creationTime.map(value => CreationTime.unwrap(value): Instant)
      )(_.creationTime)
      .build()
  }
  def asReadOnly: zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly =
    zio.aws.fsx.model.DataRepositoryAssociation.wrap(buildAwsValue())
}
object DataRepositoryAssociation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.DataRepositoryAssociation =
      zio.aws.fsx.model.DataRepositoryAssociation(
        associationId.map(value => value),
        resourceARN.map(value => value),
        fileSystemId.map(value => value),
        lifecycle.map(value => value),
        failureDetails.map(value => value.asEditable),
        fileSystemPath.map(value => value),
        dataRepositoryPath.map(value => value),
        batchImportMetaDataOnCreate.map(value => value),
        importedFileChunkSize.map(value => value),
        s3.map(value => value.asEditable),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        creationTime.map(value => value)
      )
    def associationId: Optional[DataRepositoryAssociationId]
    def resourceARN: Optional[ResourceARN]
    def fileSystemId: Optional[FileSystemId]
    def lifecycle: Optional[zio.aws.fsx.model.DataRepositoryLifecycle]
    def failureDetails
        : Optional[zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly]
    def fileSystemPath: Optional[Namespace]
    def dataRepositoryPath: Optional[ArchivePath]
    def batchImportMetaDataOnCreate: Optional[BatchImportMetaDataOnCreate]
    def importedFileChunkSize: Optional[Megabytes]
    def s3: Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly]
    def tags: Optional[List[zio.aws.fsx.model.Tag.ReadOnly]]
    def creationTime: Optional[CreationTime]
    def getAssociationId: ZIO[Any, AwsError, DataRepositoryAssociationId] =
      AwsError.unwrapOptionField("associationId", associationId)
    def getResourceARN: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARN", resourceARN)
    def getFileSystemId: ZIO[Any, AwsError, FileSystemId] =
      AwsError.unwrapOptionField("fileSystemId", fileSystemId)
    def getLifecycle
        : ZIO[Any, AwsError, zio.aws.fsx.model.DataRepositoryLifecycle] =
      AwsError.unwrapOptionField("lifecycle", lifecycle)
    def getFailureDetails: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly
    ] = AwsError.unwrapOptionField("failureDetails", failureDetails)
    def getFileSystemPath: ZIO[Any, AwsError, Namespace] =
      AwsError.unwrapOptionField("fileSystemPath", fileSystemPath)
    def getDataRepositoryPath: ZIO[Any, AwsError, ArchivePath] =
      AwsError.unwrapOptionField("dataRepositoryPath", dataRepositoryPath)
    def getBatchImportMetaDataOnCreate
        : ZIO[Any, AwsError, BatchImportMetaDataOnCreate] =
      AwsError.unwrapOptionField(
        "batchImportMetaDataOnCreate",
        batchImportMetaDataOnCreate
      )
    def getImportedFileChunkSize: ZIO[Any, AwsError, Megabytes] =
      AwsError.unwrapOptionField("importedFileChunkSize", importedFileChunkSize)
    def getS3: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("s3", s3)
    def getTags: ZIO[Any, AwsError, List[zio.aws.fsx.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getCreationTime: ZIO[Any, AwsError, CreationTime] =
      AwsError.unwrapOptionField("creationTime", creationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ) extends zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly {
    override val associationId: Optional[DataRepositoryAssociationId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.associationId())
        .map(value =>
          zio.aws.fsx.model.primitives.DataRepositoryAssociationId(value)
        )
    override val resourceARN: Optional[ResourceARN] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceARN())
      .map(value => zio.aws.fsx.model.primitives.ResourceARN(value))
    override val fileSystemId: Optional[FileSystemId] = zio.aws.core.internal
      .optionalFromNullable(impl.fileSystemId())
      .map(value => zio.aws.fsx.model.primitives.FileSystemId(value))
    override val lifecycle
        : Optional[zio.aws.fsx.model.DataRepositoryLifecycle] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lifecycle())
        .map(value => zio.aws.fsx.model.DataRepositoryLifecycle.wrap(value))
    override val failureDetails
        : Optional[zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.failureDetails())
        .map(value =>
          zio.aws.fsx.model.DataRepositoryFailureDetails.wrap(value)
        )
    override val fileSystemPath: Optional[Namespace] = zio.aws.core.internal
      .optionalFromNullable(impl.fileSystemPath())
      .map(value => zio.aws.fsx.model.primitives.Namespace(value))
    override val dataRepositoryPath: Optional[ArchivePath] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataRepositoryPath())
        .map(value => zio.aws.fsx.model.primitives.ArchivePath(value))
    override val batchImportMetaDataOnCreate
        : Optional[BatchImportMetaDataOnCreate] = zio.aws.core.internal
      .optionalFromNullable(impl.batchImportMetaDataOnCreate())
      .map(value =>
        zio.aws.fsx.model.primitives.BatchImportMetaDataOnCreate(value)
      )
    override val importedFileChunkSize: Optional[Megabytes] =
      zio.aws.core.internal
        .optionalFromNullable(impl.importedFileChunkSize())
        .map(value => zio.aws.fsx.model.primitives.Megabytes(value))
    override val s3
        : Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3())
        .map(value =>
          zio.aws.fsx.model.S3DataRepositoryConfiguration.wrap(value)
        )
    override val tags: Optional[List[zio.aws.fsx.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.fsx.model.Tag.wrap(item)
          }.toList
        )
    override val creationTime: Optional[CreationTime] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.fsx.model.primitives.CreationTime(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ): zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fsx_3-5.19.8.2-sources.jar: zio/aws/fsx/model/DataRepositoryAssociation.scala <==
package zio.aws.fsx.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.fsx.model.primitives.{
  CreationTime,
  BatchImportMetaDataOnCreate,
  Megabytes,
  FileCacheId,
  Namespace,
  FileSystemId,
  ResourceARN,
  ArchivePath,
  DataRepositoryAssociationId
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DataRepositoryAssociation(
    associationId: Optional[DataRepositoryAssociationId] = Optional.Absent,
    resourceARN: Optional[ResourceARN] = Optional.Absent,
    fileSystemId: Optional[FileSystemId] = Optional.Absent,
    lifecycle: Optional[zio.aws.fsx.model.DataRepositoryLifecycle] =
      Optional.Absent,
    failureDetails: Optional[zio.aws.fsx.model.DataRepositoryFailureDetails] =
      Optional.Absent,
    fileSystemPath: Optional[Namespace] = Optional.Absent,
    dataRepositoryPath: Optional[ArchivePath] = Optional.Absent,
    batchImportMetaDataOnCreate: Optional[BatchImportMetaDataOnCreate] =
      Optional.Absent,
    importedFileChunkSize: Optional[Megabytes] = Optional.Absent,
    s3: Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.fsx.model.Tag]] = Optional.Absent,
    creationTime: Optional[CreationTime] = Optional.Absent,
    fileCacheId: Optional[FileCacheId] = Optional.Absent,
    fileCachePath: Optional[Namespace] = Optional.Absent,
    dataRepositorySubdirectories: Optional[Iterable[Namespace]] =
      Optional.Absent,
    nfs: Optional[zio.aws.fsx.model.NFSDataRepositoryConfiguration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation = {
    import DataRepositoryAssociation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
      .builder()
      .optionallyWith(
        associationId.map(value =>
          DataRepositoryAssociationId.unwrap(value): java.lang.String
        )
      )(_.associationId)
      .optionallyWith(
        resourceARN.map(value => ResourceARN.unwrap(value): java.lang.String)
      )(_.resourceARN)
      .optionallyWith(
        fileSystemId.map(value => FileSystemId.unwrap(value): java.lang.String)
      )(_.fileSystemId)
      .optionallyWith(lifecycle.map(value => value.unwrap))(_.lifecycle)
      .optionallyWith(failureDetails.map(value => value.buildAwsValue()))(
        _.failureDetails
      )
      .optionallyWith(
        fileSystemPath.map(value => Namespace.unwrap(value): java.lang.String)
      )(_.fileSystemPath)
      .optionallyWith(
        dataRepositoryPath.map(value =>
          ArchivePath.unwrap(value): java.lang.String
        )
      )(_.dataRepositoryPath)
      .optionallyWith(
        batchImportMetaDataOnCreate.map(value =>
          BatchImportMetaDataOnCreate.unwrap(value): java.lang.Boolean
        )
      )(_.batchImportMetaDataOnCreate)
      .optionallyWith(
        importedFileChunkSize.map(value => Megabytes.unwrap(value): Integer)
      )(_.importedFileChunkSize)
      .optionallyWith(s3.map(value => value.buildAwsValue()))(_.s3)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        creationTime.map(value => CreationTime.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        fileCacheId.map(value => FileCacheId.unwrap(value): java.lang.String)
      )(_.fileCacheId)
      .optionallyWith(
        fileCachePath.map(value => Namespace.unwrap(value): java.lang.String)
      )(_.fileCachePath)
      .optionallyWith(
        dataRepositorySubdirectories.map(value =>
          value.map { item =>
            Namespace.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.dataRepositorySubdirectories)
      .optionallyWith(nfs.map(value => value.buildAwsValue()))(_.nfs)
      .build()
  }
  def asReadOnly: zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly =
    zio.aws.fsx.model.DataRepositoryAssociation.wrap(buildAwsValue())
}
object DataRepositoryAssociation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.DataRepositoryAssociation =
      zio.aws.fsx.model.DataRepositoryAssociation(
        associationId.map(value => value),
        resourceARN.map(value => value),
        fileSystemId.map(value => value),
        lifecycle.map(value => value),
        failureDetails.map(value => value.asEditable),
        fileSystemPath.map(value => value),
        dataRepositoryPath.map(value => value),
        batchImportMetaDataOnCreate.map(value => value),
        importedFileChunkSize.map(value => value),
        s3.map(value => value.asEditable),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        creationTime.map(value => value),
        fileCacheId.map(value => value),
        fileCachePath.map(value => value),
        dataRepositorySubdirectories.map(value => value),
        nfs.map(value => value.asEditable)
      )
    def associationId: Optional[DataRepositoryAssociationId]
    def resourceARN: Optional[ResourceARN]
    def fileSystemId: Optional[FileSystemId]
    def lifecycle: Optional[zio.aws.fsx.model.DataRepositoryLifecycle]
    def failureDetails
        : Optional[zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly]
    def fileSystemPath: Optional[Namespace]
    def dataRepositoryPath: Optional[ArchivePath]
    def batchImportMetaDataOnCreate: Optional[BatchImportMetaDataOnCreate]
    def importedFileChunkSize: Optional[Megabytes]
    def s3: Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly]
    def tags: Optional[List[zio.aws.fsx.model.Tag.ReadOnly]]
    def creationTime: Optional[CreationTime]
    def fileCacheId: Optional[FileCacheId]
    def fileCachePath: Optional[Namespace]
    def dataRepositorySubdirectories: Optional[List[Namespace]]
    def nfs: Optional[zio.aws.fsx.model.NFSDataRepositoryConfiguration.ReadOnly]
    def getAssociationId: ZIO[Any, AwsError, DataRepositoryAssociationId] =
      AwsError.unwrapOptionField("associationId", associationId)
    def getResourceARN: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARN", resourceARN)
    def getFileSystemId: ZIO[Any, AwsError, FileSystemId] =
      AwsError.unwrapOptionField("fileSystemId", fileSystemId)
    def getLifecycle
        : ZIO[Any, AwsError, zio.aws.fsx.model.DataRepositoryLifecycle] =
      AwsError.unwrapOptionField("lifecycle", lifecycle)
    def getFailureDetails: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly
    ] = AwsError.unwrapOptionField("failureDetails", failureDetails)
    def getFileSystemPath: ZIO[Any, AwsError, Namespace] =
      AwsError.unwrapOptionField("fileSystemPath", fileSystemPath)
    def getDataRepositoryPath: ZIO[Any, AwsError, ArchivePath] =
      AwsError.unwrapOptionField("dataRepositoryPath", dataRepositoryPath)
    def getBatchImportMetaDataOnCreate
        : ZIO[Any, AwsError, BatchImportMetaDataOnCreate] =
      AwsError.unwrapOptionField(
        "batchImportMetaDataOnCreate",
        batchImportMetaDataOnCreate
      )
    def getImportedFileChunkSize: ZIO[Any, AwsError, Megabytes] =
      AwsError.unwrapOptionField("importedFileChunkSize", importedFileChunkSize)
    def getS3: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("s3", s3)
    def getTags: ZIO[Any, AwsError, List[zio.aws.fsx.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getCreationTime: ZIO[Any, AwsError, CreationTime] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getFileCacheId: ZIO[Any, AwsError, FileCacheId] =
      AwsError.unwrapOptionField("fileCacheId", fileCacheId)
    def getFileCachePath: ZIO[Any, AwsError, Namespace] =
      AwsError.unwrapOptionField("fileCachePath", fileCachePath)
    def getDataRepositorySubdirectories: ZIO[Any, AwsError, List[Namespace]] =
      AwsError.unwrapOptionField(
        "dataRepositorySubdirectories",
        dataRepositorySubdirectories
      )
    def getNfs: ZIO[
      Any,
      AwsError,
      zio.aws.fsx.model.NFSDataRepositoryConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("nfs", nfs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ) extends zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly {
    override val associationId: Optional[DataRepositoryAssociationId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.associationId())
        .map(value =>
          zio.aws.fsx.model.primitives.DataRepositoryAssociationId(value)
        )
    override val resourceARN: Optional[ResourceARN] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceARN())
      .map(value => zio.aws.fsx.model.primitives.ResourceARN(value))
    override val fileSystemId: Optional[FileSystemId] = zio.aws.core.internal
      .optionalFromNullable(impl.fileSystemId())
      .map(value => zio.aws.fsx.model.primitives.FileSystemId(value))
    override val lifecycle
        : Optional[zio.aws.fsx.model.DataRepositoryLifecycle] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lifecycle())
        .map(value => zio.aws.fsx.model.DataRepositoryLifecycle.wrap(value))
    override val failureDetails
        : Optional[zio.aws.fsx.model.DataRepositoryFailureDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.failureDetails())
        .map(value =>
          zio.aws.fsx.model.DataRepositoryFailureDetails.wrap(value)
        )
    override val fileSystemPath: Optional[Namespace] = zio.aws.core.internal
      .optionalFromNullable(impl.fileSystemPath())
      .map(value => zio.aws.fsx.model.primitives.Namespace(value))
    override val dataRepositoryPath: Optional[ArchivePath] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataRepositoryPath())
        .map(value => zio.aws.fsx.model.primitives.ArchivePath(value))
    override val batchImportMetaDataOnCreate
        : Optional[BatchImportMetaDataOnCreate] = zio.aws.core.internal
      .optionalFromNullable(impl.batchImportMetaDataOnCreate())
      .map(value =>
        zio.aws.fsx.model.primitives.BatchImportMetaDataOnCreate(value)
      )
    override val importedFileChunkSize: Optional[Megabytes] =
      zio.aws.core.internal
        .optionalFromNullable(impl.importedFileChunkSize())
        .map(value => zio.aws.fsx.model.primitives.Megabytes(value))
    override val s3
        : Optional[zio.aws.fsx.model.S3DataRepositoryConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3())
        .map(value =>
          zio.aws.fsx.model.S3DataRepositoryConfiguration.wrap(value)
        )
    override val tags: Optional[List[zio.aws.fsx.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.fsx.model.Tag.wrap(item)
          }.toList
        )
    override val creationTime: Optional[CreationTime] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.fsx.model.primitives.CreationTime(value))
    override val fileCacheId: Optional[FileCacheId] = zio.aws.core.internal
      .optionalFromNullable(impl.fileCacheId())
      .map(value => zio.aws.fsx.model.primitives.FileCacheId(value))
    override val fileCachePath: Optional[Namespace] = zio.aws.core.internal
      .optionalFromNullable(impl.fileCachePath())
      .map(value => zio.aws.fsx.model.primitives.Namespace(value))
    override val dataRepositorySubdirectories: Optional[List[Namespace]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataRepositorySubdirectories())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.fsx.model.primitives.Namespace(item)
          }.toList
        )
    override val nfs
        : Optional[zio.aws.fsx.model.NFSDataRepositoryConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nfs())
        .map(value =>
          zio.aws.fsx.model.NFSDataRepositoryConfiguration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.DataRepositoryAssociation
  ): zio.aws.fsx.model.DataRepositoryAssociation.ReadOnly = new Wrapper(impl)
}
